Module layout

Module layout 

Pose-free spatial layout parsing and Scene builders.

Structs

PanelLayout
A single anchored panel in a spatial layout.
PanelPlacement
A persisted Viture panel placement.
SpatialLayout
A spatial layout made of anchored panels.
WorkspaceLayout
Persisted co-use layout shared by the Viture workspace and Halo glance path.

Enums

GlancePreference
Halo glance selection policy stored with a workspace layout.

Constants

WORKSPACE_LAYOUT_KIND
Kind name for persisted glasses workspace layout records.
WORKSPACE_LAYOUT_NAMESPACE
Namespace for persisted glasses workspace layout records.
WORKSPACE_LAYOUT_TABLE_NAMESPACE
Namespace used for table keys that store glasses workspace layouts.

Functions

arrange_spatial_panels
Wraps a flat Scene in a pose-free scene/spatial panel layout.
layout_expr
Returns optional spatial layout metadata embedded in a value.
layout_load_op
Builds a table/get operation loading the layout stored at path.
layout_save_op
Builds a table/set operation storing layout at path.
layout_table_key
Builds the table key used for persisted workspace layouts.