pub fn viture_loop(
profile: &DeviceProfile,
max_predict_ms: u64,
) -> (VitureReprojectLoop, FrameClock)Expand description
Builds the Viture reprojection loop and modeled clock from its profile rate.
pub fn viture_loop(
profile: &DeviceProfile,
max_predict_ms: u64,
) -> (VitureReprojectLoop, FrameClock)Builds the Viture reprojection loop and modeled clock from its profile rate.