XrMicChunkRef

Struct XrMicChunkRef 

pub struct XrMicChunkRef {
    pub ref_id: Symbol,
    pub seq: u64,
    pub sample_rate_hz: u32,
    pub channels: u8,
    pub byte_len: u64,
}
A by-reference glasses microphone chunk.

Fields

ref_id: Symbol

Store key or stream key for the referenced audio chunk.

seq: u64

Monotonic capture sequence.

sample_rate_hz: u32

PCM sample rate.

channels: u8

Number of PCM channels.

byte_len: u64

Referenced audio byte length.

Implementations

Source

impl XrMicChunkRef

pub fn new( ref_id: Symbol, seq: u64, sample_rate_hz: u32, channels: u8, byte_len: u64, ) -> Result<Self>

Builds a microphone chunk reference.

pub fn to_expr(&self) -> Expr

Encodes this reference as expression data.

pub fn from_expr(expr: &Expr) -> Result<Self>

Decodes a microphone chunk reference, rejecting embedded audio or text.