VioTrackingStatus

Enum VioTrackingStatus 

pub enum VioTrackingStatus {
    Stable6Dof,
    Limited,
    Lost,
}
VIO stability state used by the spatial world-anchor resolver.

Variants



Stable6Dof

Six degree-of-freedom tracking is stable enough for world-locked panels.



Limited

Tracking is present but not stable enough to keep panels world locked.



Lost

Tracking is unavailable.

Implementations

Source

impl VioTrackingStatus

pub fn is_stable(self) -> bool

Returns whether this status can keep world anchors locked.

pub fn to_symbol(self) -> Symbol

Encodes the status as the shared XR tracking symbol.

pub fn from_symbol(symbol: &Symbol) -> Result<Self>

Decodes the shared XR tracking symbol into resolver status.

pub fn to_expr(self) -> Expr

Encodes the status as portable expression data.

pub fn from_expr(expr: &Expr) -> Result<Self>

Decodes portable expression data into resolver status.